<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use backend\models\MailForm;
use common\helpers\GlobalParam;
use kartik\mpdf\Pdf;
use domain\PointSale\PointSale\PointSale;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;

/**
 * UserController implements the CRUD actions for User model.
 */
class CommunicateController extends BackendController
{
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::class,
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserModule()
                                ->getAuthorizationChecker()
                                ->isGrantedAsProducer($this->getUserCurrent());
                        }
                    ]
                ],
            ],
        ];
    }

    public function actionEmail(
        $idPointSale = 0,
        $sectionSubscribers = 0,
        $sectionInactiveUsers = 0,
        $usersPointSaleLink = 0,
        $usersPointSaleHasOrder = 0,
        $idDistribution = 0)
    {
        $producerCurrent = $this->getProducerCurrent();
        $userModule = $this->getUserModule();
        $distributionModule = $this->getDistributionModule();
        $mailForm = new MailForm();

        if ($idPointSale && !$usersPointSaleLink && !$usersPointSaleHasOrder) {
            $usersPointSaleLink = 1;
        }
        if ($idDistribution && !$usersPointSaleLink && !$usersPointSaleHasOrder) {
            $usersPointSaleLink = 1;
        }

        if($idDistribution) {
            $users = [];
            $distribution = $distributionModule->getRepository()->findOneDistributionById($idDistribution);
            if($distribution) {
                $mailForm->id_distribution = $idDistribution;
                foreach($distribution->pointSaleDistribution as $pointSaleDistribution) {
                    if($pointSaleDistribution->delivery) {
                        $usersPointSaleArray = $userModule->getRepository()->queryUsersBy([
                            'id_producer' => $producerCurrent->id,
                            'id_point_sale' => $pointSaleDistribution->id_point_sale,
                            'users_point_sale_link' => $usersPointSaleLink,
                            'users_point_sale_has_order' => $usersPointSaleHasOrder,
                            'newsletter' => true
                        ])->all();

                        foreach($usersPointSaleArray as $user) {
                            $users[$user['id']] = $user;
                        }
                    }
                }
            }
        }
        else {
            $users = $userModule->queryUsersBy([
                'id_producer' => GlobalParam::getCurrentProducerId(),
                'id_point_sale' => $idPointSale,
                'users_point_sale_link' => $usersPointSaleLink,
                'users_point_sale_has_order' => $usersPointSaleHasOrder,
                'subscribers' => $sectionSubscribers,
                'inactive' => $sectionInactiveUsers,
                'newsletter' => true
            ])->all();
        }

        $usersArray = [];
        foreach ($users as $key => $user) {
            if (isset($user['email']) && strlen($user['email']) > 0) {
                $usersArray[] = $user['email'];
            } else {
                unset($users[$key]);
            }
        }

        $pointsSaleArray = PointSale::find()->where(['id_producer' => GlobalParam::getCurrentProducerId(), 'status' => 1])->all();

        $pointSale = null;
        if ($idPointSale) {
            $pointSale = PointSale::findOne(['id' => $idPointSale]);
        }


        if ($mailForm->load(\Yii::$app->request->post()) && $mailForm->validate()) {
            $responseSendMail = $mailForm->sendEmail($users);
            if ($responseSendMail->success()) {
                $this->setFlash('success', 'Votre email a bien été envoyé.');
            } else {
                $bodyResponseSendMail = $responseSendMail->getBody();
                $emailsErrorArray = [];

                if (isset($bodyResponseSendMail['Messages'])) {
                    foreach ($bodyResponseSendMail['Messages'] as $message) {
                        if ($message['Status'] != 'success') {
                            $emailsErrorArray[] = $message['Errors'][0]['ErrorMessage'];
                        }
                    }
                }

                $messageError = 'Un problème est survenu lors de l\'envoi de votre email.';
                if (count($emailsErrorArray) > 0) {
                    $messageError .= '<br />Problème détecté : ' . implode(',', $emailsErrorArray);
                }
                $this->setFlash('error', $messageError);
            }

            return $this->redirect(['email', 'idPointSale' => $idPointSale]);
        }

        $incomingDistributionsArray = $distributionModule->findDistributionsIncoming();
        $incomingDistributionsDatesArray = ['0' => '--'];
        foreach ($incomingDistributionsArray as $distribution) {
            $incomingDistributionsDatesArray[$distribution->id] = strftime('%A %d %B %Y', strtotime($distribution->date));
        }

        return $this->render('email', [
            'usersArray' => $usersArray,
            'pointsSaleArray' => $pointsSaleArray,
            'pointSale' => $pointSale,
            'mailForm' => $mailForm,
            'idPointSaleActive' => $idPointSale,
            'idDistributionActive' => $idDistribution,
            'incomingDistributionsArray' => $incomingDistributionsArray,
            'incomingDistributionsDatesArray' => $incomingDistributionsDatesArray,
            'sectionSubscribers' => $sectionSubscribers,
            'sectionInactiveUsers' => $sectionInactiveUsers,
            'usersPointSaleLink' => $usersPointSaleLink,
            'usersPointSaleHasOrder' => $usersPointSaleHasOrder,
        ]);
    }

    public function actionPaper()
    {
        $producer = $this->getProducerCurrent();

        return $this->render('paper', [
            'producer' => $producer,
        ]);
    }

    /**
     * Génére un PDF contenant le mode d'emploi d'utilisation de la plateforme
     * à destination des clients des producteurs.
     *
     * @return string
     */
    public function actionInstructions()
    {
        $producer = $this->getProducerCurrent();

        // get your HTML raw content without any layouts or scripts
        $content = $this->renderPartial('instructions_multi', [
            'pdf' => true,
            'producer' => $producer
        ]);

        $pdf = new Pdf([
            // set to use core fonts only
            'mode' => Pdf::MODE_UTF8,
            // A4 paper format
            'format' => Pdf::FORMAT_A4,
            // portrait orientation
            'orientation' => Pdf::ORIENT_PORTRAIT,
            // stream to browser inline
            'destination' => Pdf::DEST_BROWSER,
            // your html content input
            'content' => $content,
            'marginRight' => 0,
            'marginLeft' => 0,
            'marginTop' => 0,
            'marginBottom' => 0,
            // format content from your own css file if needed or use the
            // enhanced bootstrap css built by Krajee for mPDF formatting 
            //'cssFile' => '@vendor/kartik-v/yii2-mpdf/assets/kv-mpdf-bootstrap.min.css',
            'cssFile' => '@app/web/css/screen.css',
            // any css to be embedded if required
            //'cssInline' => '.kv-heading-1{font-size:18px}',
            // set mPDF properties on the fly
            //'options' => ['title' => 'Krajee Report Title'],
            // call mPDF methods on the fly

            /* 'methods' => [
              'SetHeader'=>['Commandes du '.$date_str],
              'SetFooter'=>['{PAGENO}'],
              ] */
        ]);

        // return the pdf output as per the destination setting
        return $pdf->render();
    }
}
