<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace backend\controllers;

use common\helpers\Price;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;

class DashboardAdminController extends BackendController
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::class,
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@'],
                        'matchCallback' => function ($rule, $action) {
                            return $this->getUserModule()
                                ->getAuthorizationChecker()
                                ->isGrantedAsAdministrator($this->getUserCurrent());
                        }
                    ],
                ],
            ],
        ];
    }

    public function actionIndex()
    {
        return $this->render('index', [
            'supportOnline' => $this->getSettingModule()->getAdminSettingBag()->get('supportOnline'),
            'countUsersOnline' => $this->getUserModule()->getRepository()->countUsersOnline(),
            'countTicketsAdminOpen' => $this->getTicketModule()->getRepository()->countTicketsAdminStatusOpen(),
            'countTicketsAdminUnread' => $this->getTicketModule()->getRepository()->countTicketsAdminUnreadByUser($this->getUserCurrent()),
            'usersWithStatusProducerOnlineArray' => $this->getUserModule()->getRepository()->findUsersWithStatusProducerAndOnline()
            //'statisticsCacheHtml' => \Yii::$app->cache->get('dashboard_statistics12') ?: '',
        ]);
    }

    public function actionSupportOnlineToggle(int $active)
    {
        $this->getSettingModule()->getAdminSettingBag()->set('supportOnline', $active);
        return $this->redirect('index');
    }

    public function actionAjaxStatisticsHtml()
    {
        return \Yii::$app->cache->getOrSet('dashboard_statistics12', function () {
            $producerModule = $this->getProducerModule();
            $pointSaleModule = $this->getPointSaleModule();
            $userModule = $this->getUserModule();
            $orderModule = $this->getOrderModule();

            $countProducersActive = $producerModule->getRepository()->countProducersActiveWithTurnover();
            $countPointSalesActive = $pointSaleModule->countPointSalesActiveLastThreeMonths();
            $countUsersActive = $userModule->countUsersActiveLastThreeMonths();
            $averageOrdersPerDay = $orderModule->countGlobalUserOrdersAverageLastSevenDays();
            $turnoverLastThirtyDays = $orderModule->getRepository()->getTurnoverLastThirtyDays();
            $resultMatomoApiVisitSummary = json_decode(file_get_contents(\Yii::$app->parameterBag->get('matomoApiVisitSummaryUrl')));
            $numberVisitsDay = $resultMatomoApiVisitSummary->nb_uniq_visitors / 30;
            $amountBilledLastMonth = $producerModule->getRepository()->getAmountBilledLastMonth();
            $amountToBillCurrentMonth = $producerModule->getRepository()->getAmountToBillCurrentMonth();
            $amountProducerUnpaidInvoices = $producerModule->getDolibarrUtils()->getAmountProducerInvoicesUnpaid();

            return $this->renderPartial('_statistics', [
                'amountBilledLastMonth' => $amountBilledLastMonth,
                'amountToBillCurrentMonth' => $amountToBillCurrentMonth,
                'amountProducerUnpaidInvoices' => $amountProducerUnpaidInvoices,
                'countProducersActive' => $countProducersActive,
                'countPointSalesActive' => $countPointSalesActive,
                'countUsersActive' => $countUsersActive,
                'averageOrdersPerDay' => $averageOrdersPerDay,
                'turnoverLastThirtyDays' => $turnoverLastThirtyDays,
                'numberVisitsDay' => $numberVisitsDay
            ]);
        }, 60 * 60 * 24);
    }
}
