<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\GlobalParam;
use common\helpers\Price;
use domain\Order\Order\Order;
use domain\Producer\Producer\ProducerModule;
use domain\User\User\UserModule;
use domain\User\UserProducer\UserProducer;
use yii\grid\GridView;
use yii\helpers\Html;
use domain\User\UserGroup\UserGroupModule;

$userModule = UserModule::getInstance();
$producerModule = ProducerModule::getInstance();
$userCurrent = GlobalParam::getCurrentUser();
$userGroupModule = UserGroupModule::getInstance();

$this->setTitle('Utilisateurs');
$this->addBreadcrumb($this->getTitle());
$this->addButton(['label' => 'Nouvel utilisateur <span class="glyphicon glyphicon-plus"></span>', 'url' => 'user/create', 'class' => 'btn btn-primary']);

?>

<?=

$this->render('_menu_filter', [
    'idPointSaleActive' => $idPointSaleActive,
    'idDistributionActive' => 0,
    'sectionInactiveUsers' => $sectionInactiveUsers,
    'sectionSubscribers' => $sectionSubscribers,
    'pointsSaleArray' => $pointsSaleArray,
    'section' => 'index'
]);

?>

<?= GridView::widget([
    'dataProvider' => $dataProvider,
    'filterModel' => $searchModel,
    'summary' =>
        'Affichage de <b>{begin, number}-{end, number}</b> sur <b>{totalCount, number}</b> {totalCount, plural, one{élément} other{éléments}}.'.
        $this->getProducerModule()->getProducerPageSizer()
        ->getPageSizeSummary($producer, 'user', 'Utilisateurs'),
    'columns' => [
        [
            'attribute' => 'username',
            'label' => 'Nom',
            'value' => function ($user) use ($userModule) {
                return  $userModule->getUsername($user);
            }
        ],
        [
            'attribute' => 'type',
            'label' => 'Type',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile'],
            'filter' => $userModule->getTypeChoicesArray(),
            'value' => function ($user) use ($userModule) {
                return $userModule->getTypeLabel($user['type']);
            }
        ],
        [
            'attribute' => 'contacts',
            'header' => 'Contacts',
            'format' => 'raw',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile'],
            'value' => function ($user) {
                $html = '';
                if (strlen($user['phone'])) {
                    $html .= $user['phone'];
                }
                if (strlen($user['phone']) && strlen($user['email'])) {
                    $html .= '<br />';
                }
                if (strlen($user['email'])) {
                    $html .= $user['email'];
                }
                return $html;
            }
        ],
        [
            'attribute' => 'credit',
            'format' => 'raw',
            'contentOptions' => ['class' => 'column-hide-on-mobile align-center'],
            'value' => function ($model) use ($producer) {
                $userProducer =  UserProducer::searchOne([
                    'id_user' => $model->id
                ]);
                $credit = $userProducer ? $userProducer->credit : 0;
                $classBtnCredit = $userProducer->credit_active ? 'btn-success' : 'btn-default';
                $html = '<a class="btn '.$classBtnCredit.'" href="'.Yii::$app->urlManager->createUrl(['user/credit', 'id' => $model->id]).'">'.Price::format($credit).'</a>';

                return $html;
            }
        ],
        [
            'class' => 'yii\grid\ActionColumn',
            'header' => 'Commandes',
            'template' => '{orders}',
            'headerOptions' => ['class' => 'actions column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile align-center'],
            'buttons' => [
                'orders' => function ($url, $model) {
                    $url = Yii::$app->urlManager->createUrl(['user/orders', 'id' => $model['id']]);
                    $countOrders = Order::searchCount([
                        'id_user' => $model['id'],
                    ], ['conditions' => 'date_delete IS NULL']);

                    $html = '';
                    if ($countOrders) {
                        $html .= Html::a($countOrders.' commande'.($countOrders > 1 ? 's' : ''), $url, [
                            'title' => 'Commandes', 'class' => 'btn btn-default '
                        ]);;
                    } else {
                        $html .= 'Aucune';
                    }

                    return $html;
                },
            ],
        ],
        [
            'attribute' => 'newsletter',
            'header' => "Inscrit au bulletin<br/>d'information",
            'format' => 'raw',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile align-center'],
            'filter' => [
                0 => 'Non',
                1 => 'Oui'
            ],
            'value' => function ($user) use ($userModule) {
                if($userModule->isUserSubscribedNewsletter($user)) {
                    return '<span class="label label-success">Oui</span>';
                }
                return '<span class="label label-danger">Non</span>';
            }
        ],
        [
            'attribute' => 'id_user_user_group',
            'header' => 'Groupes',
            'format' => 'raw',
            'headerOptions' => ['class' => 'column-hide-on-mobile'],
            'filterOptions' => ['class' => 'column-hide-on-mobile'],
            'contentOptions' => ['class' => 'column-hide-on-mobile'],
            'filter' => $userGroupModule->getRepository()->populateUserGroupDropdownList(false),
            'value' => function ($user) {
                $html = '';
                foreach($user->userUserGroup as $userUserGroup) {
                    $html .= '<span class="label label-default">'.$userUserGroup->userGroup->name.'</span> ';
                }
                return $html;
            }
        ],
        [
            'class' => 'yii\grid\ActionColumn',
            'template' => '{view} {update} 
                                <div class="wrapper-button-dropdown">
                                <button type="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false" class="btn btn-default dropdown-toggle"><span class="caret"></span></button> 
                                <ul class="dropdown-menu">
                                    <li>{delete}</li>
                                    <li>{switch}</li>
                                </ul></div>',
            'headerOptions' => ['class' => 'column-actions'],
            'contentOptions' => ['class' => 'column-actions'],
            'buttons' => [
                'view' => function ($url, $user) {
                    return Html::a('<span class="glyphicon glyphicon-eye-open"></span>',
                        Yii::$app->urlManager->createUrl(['user/view', 'id' => $user->id]),
                        [
                            'title' => 'Voir',
                            'class' => 'btn btn-default'
                        ]);
                },
                'update' => function ($url, $user) {
                    return Html::a('<span class="glyphicon glyphicon-pencil"></span>',
                        Yii::$app->urlManager->createUrl(['user/update', 'id' => $user->id]),
                        [
                            'title' => 'Modifier',
                            'class' => 'btn btn-default'
                        ]);
                },
                'delete' => function ($url, $model) {
                    return Html::a('<span class="glyphicon glyphicon-minus"></span> Enlever',
                        Yii::$app->urlManager->createUrl(array_merge(['user/delete', 'id' => $model->id], Yii::$app->getRequest()->getQueryParams())),
                        [
                            'title' => 'Enlever',
                            'class' => 'btn-confirm-delete'
                        ]);
                },
                'switch' => function($url, $model) use ($userModule, $userCurrent) {
                    if($userModule->getAuthorizationChecker()->isGrantedAsAdministrator($userCurrent)) {
                        return Html::a('<i class="fa fa-fw fa-user-secret"></i> Prendre la main',
                            Yii::$app->urlManager->createUrl(['user/switch-identity', 'id' => $model->id]),
                            [
                                'title' => 'Prendre la main',
                                'class' => ''
                            ]);
                    }
                }
            ],
        ],
    ],
]); ?>
