<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\Feature\Feature\Feature;
use domain\Feature\Feature\FeatureModule;
use domain\Payment\PaymentModule;
use yii\grid\GridView;

$paymentManager = PaymentModule::getInstance();
$featureChecker = FeatureModule::getInstance()->getChecker();
$producer = $this->context->getProducerCurrent();
$this->setTitle('Cagnotte <div id="credit-user">' . number_format($creditUser, 2, ',', ' ') . ' €</div>');
$this->setPageTitle('Crédit');

if ($featureChecker->isEnabled(Feature::ALIAS_ONLINE_PAYMENT) && $this->context->getProducerCurrent()->online_payment) {
    $this->addButton(
        [
            'label' => '<i class="bi bi-credit-card"></i> Créditer ma cagnotte',
            'url' => 'credit/add',
            'class' => 'btn btn-primary'
        ]
    );
}

?>

<div class="table-responsive">
<?= GridView::widget([
    'summary' => '',
    'dataProvider' => $dataProvider,
    'columns' => [
        [
            'attribute' => 'date',
            'value' => function ($model) use ($paymentManager) {
                return $paymentManager->getDate($model, true);
            }
        ],
        /*[
            'attribute' => 'id_user_action',
            'value' => function ($model) use ($paymentManager) {
                return $paymentManager->getStrUserAction($model);
            }
        ],*/
        [
            'label' => 'Type',
            'format' => 'raw',
            'value' => function ($model) use ($paymentManager) {
                return $paymentManager->getStrWording($model);
            }
        ],
        [
            'attribute' => 'mean_payment',
            'value' => function ($model) use ($paymentManager) {
                return $paymentManager->getStrMeanPayment($model);
            }
        ],
        [
            'label' => 'Montant',
            'format' => 'raw',
            'value' => function ($model) use ($paymentManager) {
                if ($paymentManager->isTypeDebit($model)) {
                    return '-&nbsp;' . $paymentManager->getAmount($model, true);
                }
                elseif($paymentManager->isTypeCredit($model)) {
                    return '<span class="payment-positive">+&nbsp;' . $paymentManager->getAmount($model, true).'</span>';
                }
                return '';
            }
        ],
    ],
]);
?>
</div>
