<?php

/** 
Copyright Souke (2018)

contact@souke.fr

Ce logiciel est un programme informatique servant à aider les producteurs 
à distribuer leur production en circuits courts. 

Ce logiciel est régi par la licence CeCILL soumise au droit français et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilité au code source et des droits de copie,
de modification et de redistribution accordés par cette licence, il n'est
offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
seule une responsabilité restreinte pèse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concédants successifs.

A cet égard  l'attention de l'utilisateur est attirée sur les risques
associés au chargement,  à l'utilisation,  à la modification et/ou au
développement et à la reproduction du logiciel par l'utilisateur étant 
donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
manipuler et qui le réserve donc à des développeurs et des professionnels
avertis possédant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
logiciel à leurs besoins dans des conditions permettant d'assurer la
sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 

Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accepté les
termes.
*/

use domain\Order\Order\Order;
use domain\Order\Order\OrderModule;
use domain\Producer\Producer\ProducerModule;
use yii\grid\GridView;

$orderModule = OrderModule::getInstance();
$producerModule = ProducerModule::getInstance();
$producer = $this->context->getProducerCurrent();
$this->setTitle('Mes commandes') ;
//$this->addButton(['label' => '<i class="bi bi-pencil-square"></i> Ajouter', 'url' => 'order/order', 'class' => 'btn btn-primary']) ;

?>

<div id="index-order">

    <?php if($orderOk): ?>
            <div class="alert alert-success">
                    <div class="icon"></div>
                    Votre commande a bien été prise en compte.
            </div>
    <?php endif; ?>

    <?php if($cancelOk): ?>
            <div class="alert alert-success"><div class="icon"></div>Votre commande a bien été annulée.</div>
    <?php endif; ?>

<ul id="tabs-orders-history" class="nav nav-tabs" role="tablist">
    <li class="nav-item">
        <a class="nav-link<?php if($type == 'incoming'): ?> active<?php endif; ?>" href="<?= \Yii::$app->urlManagerProducer->createUrl(['order/history', 'type' => 'incoming']); ?>">
            À venir
            <span class="badge <?php if($countIncoming): ?>text-bg-success<?php else: ?>text-bg-secondary<?php endif; ?>"><?= $countIncoming ?></span>
        </a>
    </li>
    <li class="nav-item">
        <a class="nav-link<?php if($type == 'passed'): ?> active<?php endif; ?>" href="<?= \Yii::$app->urlManagerProducer->createUrl(['order/history', 'type' => 'passed']); ?>">
            Passées
            <span class="badge text-bg-secondary"><?= $countPassed ?></span>
        </a>
    </li>
</ul>

<div class="table-responsive">
<?php if($dataProviderOrders->getTotalCount()): ?>
<?= GridView::widget([
    'dataProvider' => $dataProviderOrders,
    'summary' => '',
    'beforeRow' => function($order) use ($orderModule) {
        $orderModule->initOrder($order) ;
    },
    'columns' => [
        [
            'attribute' => 'distribution.date',
            'label' => 'Date de distribution',
            'format' => 'raw',
            'value' => function($order) use ($orderModule) {
                return $orderModule->getDateAsHtml($order) ;
            }
        ],
        [
            'label' => 'Point de vente',
            'format' => 'raw',
            'value' => function($order) use ($orderModule) {
                return $orderModule->getPointSaleSummary($order);
            }
        ],
        [
            'label' => 'Produits',
            'format' => 'raw',
            'value' => function($order) use ($orderModule) {
                return $orderModule->getCartSummary($order);
            }
        ],
        [
            'label' => 'Montant',
            'format' => 'raw',
            'value' => function($order) use ($orderModule) {
                return $orderModule->getAmountSummary($order, 'producer');
            }
        ],
        [
            'label' => 'Statut',
            'format' => 'raw',
            'value' => function($order) use ($orderModule) {
                $html = '' ;
            
                if($order->date_delete) {
                    $html .= '<span class="badge text-bg-danger">Annulée</span>' ;
                }
                else {
                    if($orderModule->getState($order) == Order::STATE_DELIVERED) {
                        $html .= '<span class="badge text-bg-success">Livrée</span>' ;
                    }
                    elseif($orderModule->getState($order) == Order::STATE_PREPARATION) {
                        $html .= '<span class="badge text-bg-warning">En préparation</span>' ;
                    }
                    elseif($orderModule->getState($order) == Order::STATE_OPEN) {
                        $html .= '<span class="badge text-bg-secondary">À venir</span>' ;
                    }
                }
                
                return $html ;
            }
        ],
        [
            'label' => 'Actions',
            'format' => 'raw',
            'value' => function($order) use ($producer, $producerModule, $orderModule) {
                $html = '' ;
                if($orderModule->getState($order) == Order::STATE_OPEN) {
                        if ($producerModule->isOnlinePaymentActiveAndTypeOrder($producer)) {
                            $paymentStatus = $orderModule->getPaymentStatus($order);
                            if($paymentStatus == Order::PAYMENT_UNPAID && $order->online_payment_url) {
                                    $html .= '<a href="'.$order->online_payment_url.'" class="btn btn-default"><i class="bi bi-credit-card"></i> Payer en ligne</a>';
                            }
                        }
                        else {
                            $html .= '<a data-bs-toggle="tooltip" data-bs-placement="top" title="Modifier" href="'.Yii::$app->urlManager->createUrl(['order/order','id'=>$order->id]).'" class="btn btn-secondary"><i class="bi bi-pencil"></i></a> '.
                                    '<a data-bs-toggle="tooltip" data-bs-placement="top" title="Annuler" href="'.Yii::$app->urlManager->createUrl(['order/cancel','id'=>$order->id]).'" class="btn btn-secondary"><i class="bi bi-trash"></i></a> '.
                                    (($order->id_subscription) ? '<a data-bs-toggle="tooltip" data-bs-placement="top" title="Modifier l\'abonnement associé" href="'.Yii::$app->urlManagerProducer->createUrl(['subscription/form','id'=>$order->id_subscription]).'" class="btn btn-secondary"><i class="bi bi-arrow-repeat"></i></a>' : '') ;
                        }
                }

                return $html ;
            }
        ]
    ]
]); ?>
</div>

<?php else: ?>
    <div class="alert alert-dark">Aucun résultat n'a été trouvé.</div>
<?php endif; ?>
