<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\Image;
use common\helpers\Price;
use domain\Distribution\Distribution\DistributionModule;
use domain\Distribution\PointSaleDistribution\PointSaleDistribution;
use domain\PointSale\PointSale\PointSaleModule;
use domain\Producer\Producer\Producer;
use domain\Producer\Producer\ProducerModule;
use domain\Product\Product\ProductModule;
use yii\grid\GridView;
use yii\helpers\Html;

$productModule = ProductModule::getInstance();
$producerModule = ProducerModule::getInstance();
$distributionModule = DistributionModule::getInstance();
$pointSaleModule = PointSaleModule::getInstance();

$producer = $this->context->getProducerCurrent();

$this->setTitle('Points de vente');
$this->setPageTitle('Points de vente');

?>

<div id="points-sale">
    <?= GridView::widget([
        'dataProvider' => $dataProviderPointsSale,
        'summary' => '',
        'columns' => [
            [
                'attribute' => 'name',
                'format' => 'raw',
                'contentOptions' => ['class' => 'name'],
                'value' => function ($model) use ($pointSaleModule) {
                    $html = '<span class="the-name">' . Html::encode($model->name) . '</span>';
                    if (strlen($model->locality)) {
                        $html .= '<br />' . $pointSaleModule->getSolver()->getLocalityWithAddressTooltip($model);
                    }
                    return $html;
                }
            ],
            [
                'label' => 'Jours',
                'format' => 'raw',
                'contentOptions' => ['class' => 'days'],
                'value' => function ($model) use ($distributionModule) {

                    $producer = \Yii::$app->controller->getProducerCurrent();

                    if ($producer->behavior_home_point_sale_day_list == Producer::BEHAVIOR_HOME_POINT_SALE_DAY_LIST_WEEK) {
                        $arrayDays = [
                            'monday' => 'Lundi',
                            'tuesday' => 'Mardi',
                            'wednesday' => 'Mercredi',
                            'thursday' => 'Jeudi',
                            'friday' => 'Vendredi',
                            'saturday' => 'Samedi',
                            'sunday' => 'Dimanche'
                        ];

                        $html = '';
                        foreach ($arrayDays as $dayEn => $dayFr) {
                            $fieldDelivery = 'delivery_' . $dayEn;
                            $fieldInfos = 'infos_' . $dayEn;

                            if ($model->$fieldDelivery) {
                                $html .= '<div class="block-day"><strong>' . $dayFr . '</strong>';
                                if (strlen($model->$fieldInfos)) {
                                    $html .= '<br /><small>' . nl2br(str_replace(['[select_previous_day]', '[/select_previous_day]'], '', $model->$fieldInfos)) . '</small>';
                                }
                                $html .= '</div>';
                            }
                        }

                        return $html;
                    } elseif ($producer->behavior_home_point_sale_day_list == Producer::BEHAVIOR_HOME_POINT_SALE_DAY_LIST_INCOMING_DISTRIBUTIONS) {
                        $html = '';
                        $incomingDistributions = $distributionModule->findDistributionsIncoming();
                        $cpt = 0;
                        foreach ($incomingDistributions as $distribution) {
                            $countPointSaleDistribution = PointSaleDistribution::searchCount([
                                'id_distribution' => $distribution->id,
                                'id_point_sale' => $model->id,
                                'delivery' => 1
                            ]);
                            if ($countPointSaleDistribution) {
                                $html .= strftime('%A %d %B', strtotime($distribution->date)) . '<br />';
                            }

                            $cpt++;
                        }
                        return $html;
                    }
                }
            ]
        ],
    ]); ?>
</div>