<?php

/**
 * Copyright Souke (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use common\helpers\Image;
use common\helpers\Price;
use domain\Distribution\Distribution\DistributionModule;
use domain\Distribution\PointSaleDistribution\PointSaleDistribution;
use domain\PointSale\PointSale\PointSaleModule;
use domain\Producer\Producer\Producer;
use domain\Producer\Producer\ProducerModule;
use domain\Product\Product\ProductModule;
use yii\grid\GridView;
use yii\helpers\Html;

$productModule = ProductModule::getInstance();
$producerModule = ProducerModule::getInstance();
$distributionModule = DistributionModule::getInstance();
$pointSaleModule = PointSaleModule::getInstance();

$producer = $this->context->getProducerCurrent();

$this->setTitle('Produits');
$this->setPageTitle('Produits');

?>

<div id="products">
    <?php
    $columnsProducts = [];
    if ($hasProductPhoto) {
        $columnsProducts [] = [
            'attribute' => 'photo',
            'format' => 'raw',
            'headerOptions' => ['class' => 'photo'],
            'contentOptions' => ['class' => 'photo'],
            'value' => function ($model) {
                if (strlen($model->photo)) {
                    return '<a class="product-photo" href="'.Image::getThumbnailBig($model->photo).'" title="'.Html::encode($model->name).'"><img class="photo-product" src="'. Image::getThumbnailSmall($model->photo).'" />';
                }
                return '';
            }
        ];
    }

    $columnsProducts[] = [
        'attribute' => 'name',
        'format' => 'raw',
        'contentOptions' => ['class' => 'name product-name-description-block'],
        'value' => function ($model) {
            $html = '<div class="name">' . Html::encode($model->name) . '</div>';
            if (strlen($model->description)) {
                $html .= '<div class="description">' . Html::encode($model->description).'</div>';
            }
            if (strlen($model->recipe)) {
                $html .= '<div class="description-long"><a href="javascript:void(0);" class="show-more-link">En savoir plus</a><div class="content">' . nl2br(Html::encode($model->recipe)).'</div></div>';
            }
            return $html;
        }
    ];

    if ($hasProductWeight) {
        $columnsProducts[] = [
            'attribute' => 'weight',
            'format' => 'raw',
            'value' => function ($model) {
                if (strlen($model->weight)) {
                    return $model->weight . '&nbsp;g';
                }
                return '';
            }
        ];
    }

    $columnsProducts[] = [
        'attribute' => 'price',
        'format' => 'raw',
        'value' => function ($model) use ($productModule) {
            if ($model->price) {
                return Price::format($productModule->getPriceWithTax($model)) . '<br /><small>' . $productModule->getSolver()->strUnit($model, 'wording_unit', true) . '</small>';
            }
            return '';
        }
    ];
    ?>

    <?php if ($dataProviderProducts->query->count()) : ?>
        <div class="table-responsive">
            <?= GridView::widget([
                'dataProvider' => $dataProviderProducts,
                'summary' => '',
                'columns' => $columnsProducts
            ]); ?>
        </div>
    <?php endif; ?>

    <?php foreach ($categories as $category): ?>
        <?php if ($dataProviderProductsByCategories[$category->id]->query->count()): ?>
            <h4><?= Html::encode($category->name) ?></h4>
            <div class="table-responsive">
                <?= GridView::widget([
                    'dataProvider' => $dataProviderProductsByCategories[$category->id],
                    'summary' => '',
                    'columns' => $columnsProducts
                ]); ?>
            </div>
        <?php endif; ?>
    <?php endforeach; ?>
</div>